<?php
define('YOG_EXCERPT_MORE_TEXT',     '...');
define('YOG_EXCERPT_LENGTH',        20);
define('YOG_THUMB_WIDTH',           150);
define('YOG_THUMB_HEIGHT',          100);
define('YOG_IMAGE_WIDTH',           600);
define('YOG_IMAGE_HEIGHT',          400);
define('YOG_THEME_VERSION',         1.3);

require_once('includes/classes/nav_menu.php');
require_once('includes/classes/yog_theme.php');

$yogTheme = YogTheme::getInstance();
$yogTheme->init();

/**
 * @desc Function yog_plugin_register_new_categories which allows the addition of more categories
 *
 * @param {Array} $currentCategories
 * @return {Array}
 */
function yog_plugin_register_new_categories($currentCategories)
{
  $subcategories = array();

  /* For example registering a senior specific category for projects

  $subcategories[$currentCategories['consument']] => array(
      'senioren' => 'Senioren'
    );
    
  */

  return $subcategories;
}

/**
 * @desc Function yog_plugin_get_categories
 *
 * @param {Project} $this->mcp3Project
 * @return {Array}
 */
function yog_plugin_get_categories($mcp3Project)
{
  $categories = array();

  /* For example adding a senior specific category to projects
  if ($mcp3Project instanceof Yog3McpXmlProjectWonen)
  {
    // Bijzonderheden
    $bijzonderheden = $mcp3Project->getStringByPath('//project:Details/project:Woonruimte/project:Diversen/project:Bijzonderheden/project:Bijzonderheid/@naam');

    if (!empty($bijzonderheden))
    {
      $bijzonderheden = explode(',', $bijzonderheden);

      foreach ($bijzonderheden as $bijzonderheid)
      {
        if (trim($bijzonderheid) == 'toegankelijk voor ouderen')
        {
          $categories[] = 'senioren';
        }
      }
    }
  }*/

  return $categories;
}

/**
* @desc Generate object specs
*
* @param array $specs
* @return string
*/
function generateObjectSpecs($specs)
{
  $numColumns     = 2;
  $currentColumn  = 1;
  $html           = '';

  foreach ($specs as $label => $value)
  {
    if ($currentColumn == 1)
      $html .= '<div class="row">';

    $html .= '<div class="column column' . $currentColumn . '">';
      $html .= '<div class="label">' . $label . ':</div><div class="value">' . $value . '</div>';
    $html .= '</div>';

    if ($currentColumn == $numColumns)
    {
        $html .= '<div class="clearfix"></div>';
      $html .= '</div>';
      $currentColumn = 1;
    }
    else
    {
      $currentColumn++;
    }
  }

  // Render end in case not enough values to fit all columns
  if ($currentColumn > 1)
  {
      $html .=  '<div class="clearfix"></div>';
    $html .=  '</div>';
  }
  
  return $html;
}

/**
 * @desc Methodh which checks if a grey box should be used or not
 *
 * @param integer $id
 * @return void
 */
function yog_use_grey_box($postId)
{
  if (@get_post_meta($postId, "yog_top_paragraph_style_value", $single = true) != "")
  {
    $greyBox = @get_post_meta($postId, "yog_top_paragraph_style_value", $single = true);

    if ($greyBox == 'grey-box')
      return true;

  }

  return false;
}

/**
* @desc Get the logo
* 
* @param void
* @return string
*/
function yog_getLogoUrl()
{
  $logoOptions = get_option('yog-theme-logo');
  
  if ($logoOptions === false || empty($logoOptions['url']))
    $logoUrl = get_template_directory_uri() . '/img/logo.png';
  else
    $logoUrl = $logoOptions['url'];
    
  return $logoUrl;
}

/**
* @desc Get the header image url
* 
* @param void
* @return string
*/
function yog_getHeaderImgUrl()
{
  $options = get_option('yog-theme-header-img');
  
  if ($options === false || empty($options['url']))
    $logoUrl = get_template_directory_uri() . '/img/header.jpg';
  else
    $logoUrl = $options['url'];
    
  return $logoUrl;
}