<?php
/**
* yogNavMenu
* @author Kees Brandenburg - Yes-co
*/
class yogNavMenu
{
  const ADMIN_MENU_SLUG = 'yog_theme_admin';

  static $instance;
  private $menuItems;
  private $menuId;

  /**
  * @desc Constructor
  *
  * @param void
  * @return yogNavMenu
  */
  protected function __construct()
  {
    $navMenuLocations = get_theme_mod('nav_menu_locations');

    if (!empty($navMenuLocations) && !empty($navMenuLocations['mainMenu']))
    {
      $this->menuId = (int) $navMenuLocations['mainMenu'];
      $this->menuItems = @wp_get_nav_menu_items($this->menuId);

      // Enrich menu items with classes
      if (function_exists('_wp_menu_item_classes_by_context'))
        @_wp_menu_item_classes_by_context($this->menuItems);
    }
    else
    {
      $this->menuItems = array();
    }
  }

  /**
  * @desc Initialize Yes-co OG Nav Menu for use in public part
  *
  * @param void
  * @return  yogNavMenu
  */
  public static function initialize()
  {
    if (is_null(self::$instance))
      self::$instance = new self();

    return self::$instance;
  }

  /**
  * @desc Initialize Yes-co OG Nav Menu for use in admin
  *
  * @param void
  * @return yogThemeAdmin
  */
  public static function initializeAdmin()
  {
    $adminObject = self::initialize();
    add_theme_page(__('Theme settings'), __('Theme settings'), 'edit_themes', self::ADMIN_MENU_SLUG, array($adminObject, 'showSettings'));

    if (isset($_GET['page'] ) && $_GET['page'] == self::ADMIN_MENU_SLUG)
    {
      if (!empty($_POST))
        $adminObject->saveSettings();
    }
  }

  /**
  * @desc Get the current color
  *
  * @param void
  * @return string
  */
  public static function getCurrentColor()
  {
    $navMenu      = yogNavMenu::initialize();
    $rootItem     = $navMenu->getCurrentMenuRootItem();

    $color = get_option('yog-default-color');
    if (empty($color))
      $color = '#f9a535';

    if (!is_null($rootItem))
    {
      $currentColor = get_post_meta($rootItem->ID, 'color', true);
      if (!empty($currentColor))
        $color = $currentColor;
    }

    return $color;
  }

  /**
  * @desc Show settings form
  *
  * @param void
  * @return void
  */
  public function showSettings()
  {
    $html  = '<script type="text/javascript" src="../wp-includes/js/colorpicker.js"></script>';
    $html .= '<script type="text/javascript" src="' . get_template_directory_uri() . '/inc/js/admin.js"></script>';
    $html .= '<link rel="stylesheet" href="' . get_template_directory_uri() . '/inc/css/admin.css" type="text/css" media="all" />';
    $html .= '<div class="wrap">';
      $html .= '<div id="icon-options-general" class="icon32"><br /></div>';
	    $html .= '<h2>' . __('Theme settings') . '</h2>';
      $html .= '<form method="post" enctype="multipart/form-data" action="themes.php?page=' . self::ADMIN_MENU_SLUG . '">';

        $html .= '<h3>' . __('Pagina kleuren per hoofd menu item') . '</h3>';

        if (!empty($this->menuItems) && is_array($this->menuItems))
        {
          $html .= '<table class="form-table">';

            // Determine default color
            $defaultColor = get_option('yog-default-color');
            if (empty($defaultColor))
              $defaultColor = '#f9a535';

            // Loop through menu items
            foreach ($this->menuItems as $menuItem)
            {
              if (empty($menuItem->menu_item_parent))
              {
                // Determine selected color
                $color = get_post_meta($menuItem->ID, 'color', true);
                if (empty($color))
                  $color = $defaultColor;

                // Display row
                $html .= '<tr>';
                  $html .= '<td width="300"><label for="menuitem' . $menuItem->ID . '">' . $menuItem->title . '</label></td>';
                  $html .= '<td>';
                    $html .= '<div class="color-select-holder" id="menuitem' . $menuItem->ID . 'holder">';
                      $html .= '<div id="menuitem' . $menuItem->ID . 'color" class="color-select-example" style="background-color:' . $color . ';" onclick="colorSelect(document.getElementById(\'menuitem' . $menuItem->ID . '\'),\'menuitem' . $menuItem->ID . '\');">&nbsp;</div>';
                      $html .= '<input type="text" value="' . strtoupper($color) . '" name="menuitem[' . $menuItem->ID . ']" id="menuitem' . $menuItem->ID . '" onfocus="colorSelect(this,this.id);" />';
                    $html .= '</div>';
                  $html .= '</td>';
                $html .= '</tr>';
              }
            }

            $html .= '<tr>';
              $html .= '<td colspan="2"><br /></td>';
            $html .= '</tr>';
            $html .= '<tr>';
              $html .= '<td width="300"><label for="default-color">' . __('Standaard pagina kleur') . '</label></td>';
              $html .= '<td>';
                $html .= '<div class="color-select-holder">';
                  $html .= '<div id="default-colorcolor" class="color-select-example" style="background-color:' . $defaultColor . ';" onclick="colorSelect(document.getElementById(\'default-color\'),\'default-color\');"></div>';
                  $html .= '<input type="text" value="' . strtoupper($defaultColor) . '" name="default-color" id="default-color" onfocus="colorSelect(this,this.id);" />';
                $html .= '</div>';
              $html .= '</td>';
            $html .= '</tr>';

          $html .= '</table>';
        }
        else if (empty($this->menuId))
        {
		      $html .= '<div id="message" class="error below-h2" style="padding: 5px 10px;">Er is geen menu ingesteld. Stel dit in bij de <i>thema locaties</i> onder <a href="nav-menus.php">Weergave / Menu\'s</a></div>';
        }
        else
        {
		      $html .= '<div id="message" class="error below-h2" style="padding: 5px 10px;">Er zijn geen menu items gevonden.</div>';
        }

        // Show tags with posts
        $html .= '<h3>Post instellingen</h3>';
        $html .= '<div style="margin-bottom:10px;">';
          $html .= '<table class="form-table">';
            $html .= '<tr>';
              $html .= '<td width="300"><label for="yog_tags_with_post">Tags bij posts laten zien</label></td>';
              $html .= '<td>';
                $html .= '<input type="checkbox" value="yes" name="yog_tags_with_post" id="yog_tags_with_post"' . (get_option('yog_tags_with_post') ? ' checked="checked"' : '') . ' />';
              $html .= '</td>';
            $html .= '</tr>';
          $html .= '</table>';
        $html .= '</div>';

        // Upload logo
        $html .= '<h3>Logo</h3>';
        $html .= '<div style="margin-bottom:10px;">';
          $html .= '<img src="' . yog_getLogoUrl() . '" alt="Logo" /><br />';
          $html .= '<input type="file" name="logo" />';
        $html .= '</div>';

        // Upload header image
        $html .= '<h3>Header afbeelding homepage</h3>';
        $html .= '<div style="margin-bottom:10px;">';
          $html .= '<img src="' . yog_getHeaderImgUrl() . '" alt="Header afbeelding" /><br />';
          $html .= '<input type="file" name="header_img" />';
        $html .= '</div>';

        $html .= '<input type="submit" class="button-primary" value="Wijzigingen opslaan" />';
      $html .= '</form>';
    $html .= '</div>';
    $html .= '<div id="colorPickerDiv"></div>';

    echo $html;
  }

  /**
  * @desc Save theme settings
  *
  * @param void
  * @return void
  */
  public function saveSettings()
  {
    // Save colors
    if (!empty($_POST['menuitem']) && is_array($_POST['menuitem']) && !empty($this->menuId))
    {
      // Retrieve menu items
      $menuItems      = @wp_get_nav_menu_items($this->menuId);
      $menuItemColors = $_POST['menuitem'];

      // Loop through all available menu items
      foreach ($menuItems as $menuItem)
      {
        // Update color of menu item
        if (array_key_exists($menuItem->ID, $menuItemColors))
          @update_post_meta($menuItem->ID, 'color', $menuItemColors[$menuItem->ID]);
      }
    }

    // Save default color
    if (!empty($_POST['default-color']))
    {
      update_option('yog-default-color', $_POST['default-color']);
    }

    // Save post settings
    $settings = array('yog_tags_with_post');
    foreach ($settings as $setting)
    {
      if (!empty($_POST[$setting]))
        update_option($setting, $_POST[$setting]);
      else
        delete_option($setting);
    }

    // Save logo
    if (!empty($_FILES['logo']) && !empty($_FILES['logo']['tmp_name']))
    {
      $response = wp_handle_upload($_FILES['logo'], array('test_form' => false));
      if (!empty($response))
      {
        // Remove old logo
        $options  = get_option('yog-theme-logo');
        if (!($options === false || empty($options['file'])))
          @unlink($options['file']);

        // Update logo settings
        update_option('yog-theme-logo', $response);
      }
    }

    // Save header image
    if (!empty($_FILES['header_img']) && !empty($_FILES['header_img']['tmp_name']))
    {
      $response = wp_handle_upload($_FILES['header_img'], array('test_form' => false));
      if (!empty($response))
      {
        // Remove old image
        $options  = get_option('yog-theme-header-img');
        if (!($options === false || empty($options['file'])))
          @unlink($options['file']);

        // Update img settings
        update_option('yog-theme-header-img', $response);
      }
    }
  }

  /**
  * @desc Get the current menu item
  *
  * @param void
  * @return mixed
  */
  public function getCurrentMenuRootItem()
  {
    $currentUrl = 'http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];

    if (!empty($this->menuItems))
    {
      foreach ($this->menuItems as $menuItem)
      {
        if (!empty($menuItem->classes) && in_array('current-menu-item', $menuItem->classes) || in_array('current-menu-parent', $menuItem->classes))
        {
          while (!empty($menuItem->menu_item_parent))
          {
            $menuItem = $this->getMenuItem($menuItem->menu_item_parent);
          }

          return $menuItem;
        }
      }
    }
  }

  /**
  * @desc Get a menu item by id
  *
  * @param int $id
  * @return mixed
  */
  public function getMenuItem($id)
  {
    foreach ($this->menuItems as $menuItem)
    {
      if ($menuItem->ID == $id)
        return $menuItem;
    }
  }
}
?>