<?php
  /**
  * @desc YogTheme
  * @author Kees Brandenburg - Yes-co Nederland
  */
  abstract class YogTheme
  {
    private static $instance;

    /**
    * @desc Constructor
    *
    * @param void
    * @return YogTheme
    */
    private function __construct()
    {

    }

    /**
    * @desc Get an instance of the YogTheme
    *
    * @param void
    * @return YogTheme
    */
    static public function getInstance()
    {
      if (is_null(self::$instance))
      {
        if (is_admin())
          self::$instance = new YogThemeAdmin();
        else
          self::$instance = new YogThemePublic();
      }

      return self::$instance;
    }

    /**
    * @desc Init theme
    *
    * @param void
    * @return void
    */
    public function init()
    {
      $this->registerSideBars();

      if (function_exists('add_theme_support'))
      {
        add_theme_support('post-thumbnails');
        set_post_thumbnail_size(YOG_THUMB_WIDTH, YOG_THUMB_HEIGHT);
        add_theme_support('automatic-feed-links');
      }

      add_action('init', array($this, 'registerMenus'));
    }

    /**
    * @desc Register the menus to use in this theme
    *
    * @param void
    * @return void
    */
    public function registerMenus()
    {
      register_nav_menus(array( 'mainMenu'  => __('Menu'),
                                'topMenu'  => __('Top menu')
                                ));
    }


    /**
    * @desc Register sidebars
    *
    * @param void
    * @return void
    */
    private function registerSideBars()
    {
      if ( function_exists('register_sidebar') )
      {
        $sideBarOptions = array('before_widget' => '<div class="borderbox widget %2$s" id="%1$s">',
                                'after_widget'  => '</div>',
                                'before_title'  => '<h4 class="widgettitle">',
                                'after_title'   => '</h4>',
                            );

        register_sidebar(array_merge($sideBarOptions, array('name' => 'Homepage - Boven', 'id' => 'sidebar-1')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Homepage - Links', 'id' => 'sidebar-2')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Homepage - Rechts', 'id' => 'sidebar-3')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Pagina - Rechts', 'id' => 'sidebar-4')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Pagina - Links', 'id' => 'sidebar-5')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Category - Rechts', 'id' => 'sidebar-6')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Category - Objecten - Rechts', 'id' => 'sidebar-7')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Category - BOG Objecten - Rechts', 'id' => 'sidebar-bog-objects-right')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Category - Nieuwbouw Objecten - Rechts', 'id' => 'sidebar-nb-objects-right')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Category - Links', 'id' => 'sidebar-8')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Category - Objecten - Links', 'id' => 'sidebar-9')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Category - BOG Objecten - Links', 'id' => 'sidebar-bog-objects-left')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Category - Nieuwbouw Objecten - Links', 'id' => 'sidebar-nb-objects-left')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Aanbod detail pagina - Links', 'id' => 'sidebar-10')));

        register_sidebar(array(
            'name'          => 'Aanbod detail pagina - Onder',
            'before_widget' => '<div class="borderbox widget %2$s" id="%1$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widgettitle">',
            'after_title'   => '</h4>',
            'id'            => 'sidebar-12'
        ));

        register_sidebar(array_merge($sideBarOptions, array('name' => 'Post - Rechts', 'id' => 'sidebar-13')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Post - Links', 'id' => 'sidebar-14')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Overig - Rechts', 'id' => 'sidebar-15')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Blog - Links', 'id' => 'sidebar-16')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Blog - Rechts', 'id' => 'sidebar-17')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Zoekresultaten - Links', 'id' => 'sidebar-18')));
        register_sidebar(array_merge($sideBarOptions, array('name' => 'Zoekresultaten - Rechts', 'id' => 'sidebar-19')));
        register_sidebar(array_merge($sideBarOptions, array('name' => '404 - Links', 'id' => 'sidebar-20')));
        register_sidebar(array_merge($sideBarOptions, array('name' => '404 - Rechts', 'id' => 'sidebar-21')));

        register_sidebar(array(
            'name'          => 'Footer',
            'before_widget' => '<div class="footerbox widget %2$s" id="%1$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widgettitle noDisplay">',
            'after_title'   => '</h4>',
            'id'            => 'sidebar-22'
        ));
      }
    }
  }

  /**
  * @desc YogThemeAdmin
  * @author Kees Brandenburg - Yes-co Nederland
  */
  class YogThemeAdmin extends YogTheme
  {
    /**
    * @desc Init theme
    *
    * @param void
    * @return void
    */
    public function init()
    {
      parent::init();

      global $pagenow;

      if (is_admin() && isset($_GET['activated'] ) && $pagenow == 'themes.php')
        $this->activateTheme();

      @add_action('admin_menu',  array('yogNavMenu', 'initializeAdmin'));
      @add_action('save_post',   array($this, 'extendSavePostTopParagraphStyle'));

      if (function_exists('add_meta_box'))
        @add_meta_box('yog-top-paragraph-style', 'Yes-co Custom Page Settings', array($this, 'generateTopParagraphStyleMeta'), 'page', 'normal', 'high' );
    }

    /**
    * @desc Extend save post
    *
    * @param int $postId
    * @return void
    */
    public function extendSavePostTopParagraphStyle($postId)
    {
      // Verify
      if (get_post_type($postId) != 'page')
        return $postId;

      if (!isset($_POST['yog_top_paragraph_style_noncename']) || !wp_verify_nonce( $_POST['yog_top_paragraph_style_noncename'], plugin_basename(__FILE__) ))
        return $postId;

      if (!current_user_can( 'edit_page', $postId))
        return $postId;

      // Get data
      $data = (empty($_POST['yog_top_paragraph_style_value']) ? '' : $_POST['yog_top_paragraph_style_value']);

      // Save data
      if (!empty($data))
        update_post_meta($postId, 'yog_top_paragraph_style_value', $data);
      else
        delete_post_meta($postId, 'yog_top_paragraph_style_value');
    }

    /**
    * @desc Generate top paragraph
    */
    public function generateTopParagraphStyleMeta($post)
    {
      $value            = get_post_meta($post->ID, 'yog_top_paragraph_style_value', true);
      $supportedValues  = array('no-box' => 'Geen kader', 'grey-box' => 'Grijze kader');

      echo '<input type="hidden" name="yog_top_paragraph_style_noncename" id="yog_top_paragraph_style_noncename" value="'.wp_create_nonce( plugin_basename(__FILE__) ).'" />';
      echo '<h2>Bovenste paragraph style</h2>';
      echo '<select name="yog_top_paragraph_style_value">';

      foreach ($supportedValues as $supportedValue => $supportedLabel)
      {
        $selected = '';

        if ($value == $supportedValue)
          $selected = ' selected="selected"';

        echo '<option value="' . $supportedValue . '"' . $selected . '>' . $supportedLabel . '</option>';
      }

      echo '</select>';

      echo '<p>Toont wel of niet een grijze kader om het deel voor de "Meer" info.</p>';
    }

    /**
    * @desc Activate this theme
    *
    * @param void
    * @return void
    */
    private function activateTheme()
    {
      // Set correct media formats
      @update_option('thumbnail_size_w', YOG_THUMB_WIDTH);
      @update_option('thumbnail_size_h', YOG_THUMB_HEIGHT);
      @update_option('large_size_w',     YOG_IMAGE_WIDTH);
      @update_option('large_size_h',     YOG_IMAGE_HEIGHT);
    }
  }

  /**
  * @desc YogThemePublic
  * @author Kees Brandenburg - Yes-co Nederland
  */
  class YogThemePublic extends YogTheme
  {
    /**
    * @desc Init theme
    *
    * @param void
    * @return void
    */
    public function init()
    {
      parent::init();

      add_filter('posts_orderby',   array($this, 'extendSearchOrder'));
      add_filter('excerpt_length',  array($this, 'determineExcerptLength'));
      add_filter('excerpt_more',    array($this, 'determineExcerptMoreText'));
			add_action('init',						array($this, 'enqueueFiles'));

      // Remove WordPress version in HTML
      remove_action('wp_head', 'wp_generator');
    }
		
    /**
    * @desc Enqueue files
    *
    * @param void
    * @return void
    */
    public function enqueueFiles()
    {
      wp_enqueue_script('yog-ex-tablesorter', get_template_directory_uri() . '/inc/js/jquery.tablesorter.min.js', array('jquery'), '1.5', true);
			wp_enqueue_script('yog-ex-script', get_template_directory_uri() . '/inc/js/script.js', array('jquery'), '1.5', true);
    }

    /**
    * Overwrite the default search order
    *
    * @param string $orderby
    * @return string
    */
    public function extendSearchOrder($orderby)
    {
      if (defined('YOG_PLUGIN_INSTALLED') && is_search())
      {
        $postTypes  = yog_getAllObjectPostTypes();
        $orderby      = "(post_type IN ('" . implode("','", $postTypes) . "')) DESC, post_title ASC";
      }

      return $orderby;
    }

    /**
    * @desc Determen excerpt length
    *
    * @param int $length
    * @return $length;
    */
    public function determineExcerptLength($length)
    {
	    return YOG_EXCERPT_LENGTH;
    }

    /**
    * @desc Determine text for excerpt more
    *
    * @param string $more
    * @return string
    */
    function determineExcerptMoreText($more)
    {
	    return YOG_EXCERPT_MORE_TEXT;
    }
  }
?>